@@ -404,18 +404,15 @@ def MakeProfiles(ClustersFileName="VicinityPermissiveClustsLinear" + "RM_A" + ".
             pool.join()
 
 
-    if __name__ == __name__:
-        t1 = time.time()
-        cnt = 0
+    t1 = time.time()
+    cnt = 0
 
-        multi_process()
+    multi_process()
 
-        t2 = time.time()
+    t2 = time.time()
 
-        print("Work Done !")
-        print("Used time: ", t2 - t1, "s")
-    else:
-        print(__name__)
+    print("Work Done !")
+    print("Used time: ", t2 - t1, "s")
 
 
 # step 11
@@ -1093,10 +1090,10 @@ def SortRelevance(DefenseSystem_Name="RM_A", DefenseSystem_FilePath="./", PathTo
         reduce_known_pos.to_csv(outname,index= False)
         
         
-    if __name__ == __name__:
-        filename = Relevance_CategoryName
-        outname = DefenseSystem_FilePath+DefenseSystem_Name + '_OUTPUT/output_Relevance_Sorted_'+ DefenseSystem_Name + '_Category.csv'
-        binary_cls_analysis(filename, outname)
+
+    filename = Relevance_CategoryName
+    outname = DefenseSystem_FilePath+DefenseSystem_Name + '_OUTPUT/output_Relevance_Sorted_'+ DefenseSystem_Name + '_Category.csv'
+    binary_cls_analysis(filename, outname)
 
 
 
